@@ -17,7 +17,7 @@ pub fn criterion_benchmark(c: &mut Criterion) {
     );
 
     c.bench_function("mesh_from_sdf", |b| {
-        b.iter(|| saft::mesh_from_sdf(&graph, root, mesh_options))
+        b.iter(|| saft::mesh_from_sdf(&graph, root, mesh_options));
     });
 }
 
